require_relative '../helper'

class TestDocumentation < Test::Unit::TestCase
  GEM_NAME = 'execute_shell'
  VERSION = '1.0.2'
  README = 'README.md'
  LICENSE = [
    'license/lgplv3.md',
    'license/gplv3.md'
  ]

  test 'gemspec exists' do
    assert FileTest.file?(File.join(Dir.pwd, gemspec_file)),
      "#{gemspec_file} does not exist"
  end

  test "gemspec is version #{VERSION}" do
    assert_equal VERSION, gemspec.version.to_s
  end

  test 'gemspec has the correct gem names' do
    assert_equal GEM_NAME, gemspec.name
    assert_match gem_name_proper, gemspec.description,
      "#{gem_name_proper} does not match:\n#{gemspec.description}"
  end

  test "#{README} exists" do
    assert FileTest.file?(File.join(Dir.pwd, README)),
      "#{README} does not exist"
  end

  test 'README contains accurate information' do
    readme = File.open(File.join(Dir.pwd, README), 'r') { |f| f.read }

    assert_match gem_name_proper, readme,
      "#{gem_name_proper} does not match the contents of #{README}"
    assert_match GEM_NAME, readme,
      "#{GEM_NAME} does not match the contents of #{README}"
    assert_match gemspec.version.to_s, readme,
      "#{gemspec.version} does not match the contents of #{README}"
  end

  test 'license files exist' do
    LICENSE.each do |license|
      file = File.join(Dir.pwd, license)
      assert FileTest.file?(file), "#{file} does not exist"
    end
  end

  test 'files in lib have license text' do
    Dir["#{Dir.pwd}/lib/**/*.rb"].each do |file|
      content = File.open(file, 'r') { |f| f.read }

      assert_match(/Copyright \(C\) \d{4} Travis Herrick/, content,
        "Copyright is missing from #{file}")
      assert_match(/GNU Lesser General Public License/, content,
        "License should be LGPL in #{file}")
    end
  end

  private

  def gemspec
    return @gemspec if defined?(@gemspec)
    @gemspec = Gem::Specification.load(gemspec_file)
  end

  def gemspec_file
    "#{GEM_NAME}.gemspec"
  end

  def gem_name_proper
    GEM_NAME.capitalize.gsub(/(_[a-z])/) { $1[-1].upcase }
  end
end
